#!/bin/bash

#title:          :install.sh
#description     :This is "Malefica" plug-in installation script
#author          :Evil Sound Lab
#version         :1.0.0
#usage           :sudo /bin/bash ./install.sh
#notes           :Current script is only for Debian-based Linux.
#bash-version:   :4.3.46(1)-release
#======================================================================

#init util vars
pluginName="Malefica"
bold=$(tput bold)
normal=$(tput sgr0)
chatPrefix="${bold}Plug-in Installation:${normal} "

#check Debian compatibility
if [ ! -f /etc/debian_version ]; then
    echo "Current script is only for Debian-based Linux. Sorry."
    echo "How to install \"${pluginName}\" plug-in manually described in \"Installation Notes\" chapter of \"README.txt\" file."
    exit 0
fi

echo ""
echo "-----------------------------------------------------------"
echo "|                                                         |"
echo "|    ${bold}Welcome to \"${pluginName}\" plug-in installation script!${normal}   |"
echo "|                                                         |"
echo "-----------------------------------------------------------"
echo ""

#sure-dialog
read -n 1 -p "${chatPrefix}are you sure that you want to continue? (y/[a]): " isNeedToRun

if [ ! "$isNeedToRun" = "y" ]; then
    echo ""
    exit
fi

echo ""
echo ""

#dirty hack
echo "(0/2) ${chatPrefix} Copy awt_xawt library to mawt, because it was renamed by Oracle."
cp "${JAVA_HOME}lib/i386/libawt_xawt.so" "${JAVA_HOME}lib/i386/libmawt.so"
echo ""

#check x86_64 architecture
if [ "$(arch)" = "x86_64" ]; then
    skipArch="false"
    
    echo "(1/2) ${chatPrefix}x86_64 architecture detected, starting installation i386 bundle: libx11-6:i386, libxtst6:i386, libxrender1:i386, libxi6:i386, libxpm4:i386"
    
    for (( i=5; i>=0; i--)); do
        printf "\rin $i seconds. ${bold}Hit any key to skip.${normal}"
        read -s -n 1 -t 1 key
        if [[ $key ]]
        then
            skipArch="true"
            break;
        fi
    done
    
    if [ $skipArch = "false" ]; then
        echo ""
        echo "-----------------------------------------------------------"
        echo ""

        dpkg --add-architecture i386
        apt-get update
        apt-get -y install libc6:i386 libncurses5:i386 libstdc++6:i386
    
        //ia32-libs
        apt-get -y install lib32z1 lib32ncurses5 lib32bz2-1.0

        echo ""
        echo "-----------------------------------------------------------"
        echo "(1/2) ${chatPrefix}i368 bundle installation completed."
        sleep 1s
    else
        echo ""
        echo "${chatPrefix}installation i386 bundle was skipped."
    fi
fi

#install plug-in dependencies
skipDepend="false"

echo ""
echo "(2/2) ${chatPrefix}starting plug-in dependencies installation: libx11-6:i386, libxtst6:i386, libxrender1:i386, libxi6:i386, libxpm4:i386"

for (( i=5; i>=0; i--)); do
    printf "\rin $i seconds. ${bold}Hit any key to skip.${normal}"
    read -s -n 1 -t 1 key
    if [[ $key ]]
    then
        skipDepend="true"
        break;
    fi
done

if [ $skipDepend = "false" ]; then
    echo ""
    echo "-----------------------------------------------------------"
    echo ""

    apt-get -y install libx11-6:i386 libxtst6:i386 libxrender1:i386 libxi6:i386 libxpm4:i386

    echo ""
    echo "-----------------------------------------------------------"
    echo "(2/2) ${chatPrefix}plug-in dependencies installation completed."
else
    echo ""
    echo "${chatPrefix}installation plug-in dependencies was skipped."
fi

echo ""
if [ -z "$(ldd Malefica.so | grep not)" ]; then
    #successful
    echo "${chatPrefix}\"${pluginName}\" plug-in prepared for work!"
    echo ""
    echo "-----------------------------------------------------------"
    echo "|                                                         |"
    echo "| ${bold}\"${pluginName}\" plug-in installation successfully completed!${normal} |"
    echo "|                           ${bold}Enjoy!${normal}                        |"
    echo "|                                                         |"
    echo "-----------------------------------------------------------"
    echo ""
else
    #almost successful - there are not installed dependencies
    echo "${chatPrefix}plug-in installation completed, but, unfortunately, not all dependencies was installed. Please, install next dependencies manually:"
    ldd Malefica.so | grep not
    echo ""
    echo "${chatPrefix}For more details execute \"ldd Malefica.so\" command in terminal."
fi

exit 0
